@@ -209,3 +209,33 @@ class Matcher(ABC):
         self.__context = context
         yield
         self.__context = None
+
+
+class MatchWrapper:
+    def __init__(self, value: MatchedType, matcher: Matcher, did_match: bool):
+        self.value = value
+        self.matcher = matcher
+        self.did_match = did_match
+
+    def __bool__(self) -> bool:
+        return self.did_match
+
+    def __str__(self) -> str:
+        return f'that({self.value!r}).matches({self.matcher})'
+
+    def __repr__(self) -> str:
+        return str(self)
+
+
+class MatcherWrapper:
+    def __init__(self, value: MatchedType):
+        self.value = value
+
+    def matches(self, matcher: Matcher) -> MatchWrapper:
+        context = _MatcherContext(mismatch_expected=False, nested_call=False)
+        did_match = matcher.matches(self.value, context)
+        return MatchWrapper(self.value, matcher, did_match)
+
+
+def that(value: MatchedType) -> MatcherWrapper:
+    return MatcherWrapper(value)
